<?php

return [
    'Names' => [
        'aa' => 'අෆාර්',
        'ab' => 'ඇබ්කාසියානු',
        'ace' => 'අචයිනිස්',
        'ada' => 'අඩන්ග්මෙ',
        'ady' => 'අඩිඝෙ',
        'aeb' => 'ටියුනිසියනු අරාබි',
        'af' => 'අෆ්‍රිකාන්ස්',
        'agq' => 'ඇගම්',
        'ain' => 'අයිනු',
        'ak' => 'අකාන්',
        'ale' => 'ඇලුඑට්',
        'alt' => 'සතර්න් අල්ටය්',
        'am' => 'ඇම්හාරික්',
        'an' => 'ඇරගොනීස්',
        'ann' => 'ඔබලෝ',
        'anp' => 'අන්ගික',
        'ar' => 'අරාබි',
        'arn' => 'මපුචෙ',
        'arp' => 'ඇරපහො',
        'ars' => 'නජ්ඩි අරාබි',
        'as' => 'ඇසෑම්',
        'asa' => 'අසු',
        'ast' => 'ඇස්ටියුරියන්',
        'atj' => 'ඇටිකමෙක්ව්',
        'av' => 'ඇවරික්',
        'awa' => 'අවදි',
        'ay' => 'අයිමරා',
        'az' => 'අසර්බයිජාන්',
        'ba' => 'බාෂ්කිර්',
        'ban' => 'බැලිනීස්',
        'bas' => 'බසා',
        'be' => 'බෙලරුසියානු',
        'bem' => 'බෙම්බා',
        'bez' => 'බෙනා',
        'bg' => 'බල්ගේරියානු',
        'bgn' => 'බටහිර බලොචි',
        'bho' => 'බොජ්පුරි',
        'bi' => 'බිස්ලමා',
        'bin' => 'බිනි',
        'bla' => 'සික්සිකා',
        'bm' => 'බම්බරා',
        'bn' => 'බෙංගාලි',
        'bo' => 'ටිබෙට්',
        'br' => 'බ්‍රේටොන්',
        'brx' => 'බොඩො',
        'bs' => 'බොස්නියානු',
        'bug' => 'බුගිනීස්',
        'byn' => 'බ්ලින්',
        'ca' => 'කැටලන්',
        'cay' => 'කයුගා',
        'ccp' => 'චක්මා',
        'ce' => 'චෙච්නියානු',
        'ceb' => 'සෙබුඅනො',
        'cgg' => 'චිගා',
        'ch' => 'චමොරො',
        'chk' => 'චූකීස්',
        'chm' => 'මරි',
        'cho' => 'චොක්ටොව්',
        'chp' => 'චිපෙවියන්',
        'chr' => 'චෙරොකී',
        'chy' => 'චෙයෙන්නෙ',
        'ckb' => 'සොරානි කුර්දිෂ්',
        'clc' => 'චිල්කොටින්',
        'co' => 'කෝසිකානු',
        'crg' => 'මිචිෆ්',
        'crj' => 'දකුණු නැගෙනහිර ක්‍රී',
        'crk' => 'ප්ලේන්ස් ක්‍රී',
        'crl' => 'උතුරු නැගෙනහිර ක්‍රී',
        'crm' => 'මූස් ක්‍රී',
        'crr' => 'කැරොලිනා ඇල්ගොන්කියන්',
        'crs' => 'සෙසෙල්ව ක්‍රොල් ෆ්‍රෙන්ච්',
        'cs' => 'චෙක්',
        'csw' => 'මඩ වගුරු ක්‍රී',
        'cu' => 'චර්ච් ස්ලැවික්',
        'cv' => 'චවේෂ්',
        'cy' => 'වෙල්ෂ්',
        'da' => 'ඩැනිශ්',
        'dak' => 'ඩකොටා',
        'dar' => 'ඩාර්ග්වා',
        'dav' => 'ටයිටා',
        'de' => 'ජර්මන්',
        'dgr' => 'ඩොග්‍රිබ්',
        'dje' => 'සර්මා',
        'doi' => 'ඩොග්රි',
        'dsb' => 'පහළ සෝබියානු',
        'dua' => 'ඩුආලා',
        'dv' => 'ඩිවෙහි',
        'dyo' => 'ජොල-ෆෝනියි',
        'dz' => 'ඩිසොන්කා',
        'dzg' => 'ඩසාගා',
        'ebu' => 'එම්බු',
        'ee' => 'ඉව්',
        'efi' => 'එෆික්',
        'eka' => 'එකජුක්',
        'el' => 'ග්‍රීක',
        'en' => 'ඉංග්‍රීසි',
        'eo' => 'එස්පැරන්ටෝ',
        'es' => 'ස්පාඤ්ඤ',
        'et' => 'එස්තෝනියානු',
        'eu' => 'බාස්ක්',
        'ewo' => 'එවොන්ඩො',
        'fa' => 'පර්සියානු',
        'ff' => 'ෆුලාහ්',
        'fi' => 'ෆින්ලන්ත',
        'fil' => 'පිලිපීන',
        'fj' => 'ෆීජි',
        'fo' => 'ෆාරෝස්',
        'fon' => 'ෆොන්',
        'fr' => 'ප්‍රංශ',
        'frc' => 'කජුන් ප්‍රංශ',
        'frr' => 'උතුරු ෆ්‍රිසියානු',
        'fur' => 'ෆ්‍රියුලියන්',
        'fy' => 'බටහිර ෆ්‍රිසියානු',
        'ga' => 'අයර්ලන්ත',
        'gaa' => 'ගා',
        'gag' => 'ගගාස්',
        'gan' => 'ගැන් චයිනිස්',
        'gd' => 'ස්කොට්ටිශ් ගෙලික්',
        'gez' => 'ගීස්',
        'gil' => 'ගිල්බර්ටීස්',
        'gl' => 'ගැලීසියානු',
        'gn' => 'ගුවාරනි',
        'gor' => 'ගොරොන්ටාලො',
        'gsw' => 'ස්විස් ජර්මානු',
        'gu' => 'ගුජරාටි',
        'guz' => 'ගුසී',
        'gv' => 'මැන්ක්ස්',
        'gwi' => 'ග්විචින්',
        'ha' => 'හෝසා',
        'hai' => 'හයිඩා',
        'hak' => 'හකා චයිනිස්',
        'haw' => 'හවායි',
        'hax' => 'දකුණු හයිඩා',
        'he' => 'හීබෲ',
        'hi' => 'හින්දි',
        'hil' => 'හිලිගෙනන්',
        'hmn' => 'මොන්ග්',
        'hr' => 'කෝඒෂියානු',
        'hsb' => 'ඉහළ සෝබියානු',
        'hsn' => 'සියැන් චීන',
        'ht' => 'හයිටි',
        'hu' => 'හන්ගේරියානු',
        'hup' => 'හුපා',
        'hur' => 'හල්කොමලෙම්',
        'hy' => 'ආර්මේනියානු',
        'hz' => 'හෙරෙරො',
        'ia' => 'ඉන්ටලින්ගුආ',
        'iba' => 'ඉබන්',
        'ibb' => 'ඉබිබියො',
        'id' => 'ඉන්දුනීසියානු',
        'ig' => 'ඉග්බෝ',
        'ii' => 'සිචුආන් යී',
        'ikt' => 'බටහිර කැනේඩියානු ඉනුක්ටිටුට්',
        'ilo' => 'ඉලොකො',
        'inh' => 'ඉන්ගුෂ්',
        'io' => 'ඉඩො',
        'is' => 'අයිස්ලන්ත',
        'it' => 'ඉතාලි',
        'iu' => 'ඉනුක්ටිටුට්',
        'ja' => 'ජපන්',
        'jbo' => 'ලොජ්බන්',
        'jgo' => 'නොම්බා',
        'jmc' => 'මැකාමී',
        'jv' => 'ජාවා',
        'ka' => 'ජෝර්ජියානු',
        'kab' => 'කාබිල්',
        'kac' => 'කචින්',
        'kaj' => 'ජ්ජු',
        'kam' => 'කැම්බා',
        'kbd' => 'කබාර්ඩියන්',
        'kcg' => 'ට්යප්',
        'kde' => 'මැකොන්ඩ්',
        'kea' => 'කබුවෙර්ඩියානු',
        'kfo' => 'කොරො',
        'kgp' => 'කයිංගං',
        'kha' => 'ඛසි',
        'khq' => 'කොයිරා චිනි',
        'ki' => 'කිකුයු',
        'kj' => 'කුයන්යමා',
        'kk' => 'කසාඛ්',
        'kkj' => 'කකො',
        'kl' => 'කලාලිසට්',
        'kln' => 'කලෙන්ජන්',
        'km' => 'කමර්',
        'kmb' => 'කිම්බුන්ඩු',
        'kn' => 'කණ්ණඩ',
        'ko' => 'කොරියානු',
        'koi' => 'කොමි-පර්මියාක්',
        'kok' => 'කොන්කනි',
        'kpe' => 'ක්පෙලෙ',
        'kr' => 'කනුරි',
        'krc' => 'කරන්චි-බාකර්',
        'krl' => 'කැරෙලියන්',
        'kru' => 'කුරුඛ්',
        'ks' => 'කාෂ්මීර්',
        'ksb' => 'ශාම්බලා',
        'ksf' => 'බාෆියා',
        'ksh' => 'කොලොග්නියන්',
        'ku' => 'කුර්දි',
        'kum' => 'කුමික්',
        'kv' => 'කොමි',
        'kw' => 'කෝනීසියානු',
        'kwk' => 'ක්වාක්වාලා',
        'ky' => 'කිර්ගිස්',
        'la' => 'ලතින්',
        'lad' => 'ලඩිනො',
        'lag' => 'ලංගි',
        'lb' => 'ලක්සැම්බර්ග්',
        'lez' => 'ලෙස්ගියන්',
        'lg' => 'ගන්ඩා',
        'li' => 'ලිම්බර්ගිශ්',
        'lil' => 'ලිලූට්',
        'lkt' => 'ලකොට',
        'ln' => 'ලින්ගලා',
        'lo' => 'ලාඕ',
        'lou' => 'ලුසියානා ක්‍රියෝල්',
        'loz' => 'ලොසි',
        'lrc' => 'උතුරු ලුරි',
        'lsm' => 'සාමියා',
        'lt' => 'ලිතුවේනියානු',
        'lu' => 'ලුබා-කටන්ගා',
        'lua' => 'ලුබ-ලුලුඅ',
        'lun' => 'ලුන්ඩ',
        'luo' => 'ලුඔ',
        'lus' => 'මිසො',
        'luy' => 'ලුයියා',
        'lv' => 'ලැට්වියානු',
        'mad' => 'මදුරීස්',
        'mag' => 'මඝහි',
        'mai' => 'මයිතිලි',
        'mak' => 'මකාසාර්',
        'mas' => 'මසායි',
        'mdf' => 'මොක්ශා',
        'men' => 'මෙන්ඩෙ',
        'mer' => 'මෙරු',
        'mfe' => 'මොරිස්යෙම්',
        'mg' => 'මලගාසි',
        'mgh' => 'මඛුවා-මීටෝ',
        'mgo' => 'මෙටා',
        'mh' => 'මාශලීස්',
        'mi' => 'මාවොරි',
        'mic' => 'මික්මැක්',
        'min' => 'මිනන්ග්කබාවු',
        'mk' => 'මැසිඩෝනියානු',
        'ml' => 'මලයාලම්',
        'mn' => 'මොංගෝලියානු',
        'mni' => 'මනිපුරි',
        'moe' => 'ඉනු-අයිමුන්',
        'moh' => 'මොහොව්ක්',
        'mos' => 'මොස්සි',
        'mr' => 'මරාති',
        'ms' => 'මැලේ',
        'mt' => 'මොල්ටිස්',
        'mua' => 'මුන්ඩන්',
        'mus' => 'ක්‍රීක්',
        'mwl' => 'මිරන්ඩීස්',
        'my' => 'බුරුම',
        'myv' => 'එර්ස්යා',
        'mzn' => 'මැසන්ඩරනි',
        'na' => 'නෞරු',
        'nan' => 'මින් නන් චයිනිස්',
        'nap' => 'නියාපොලිටන්',
        'naq' => 'නාමා',
        'nb' => 'නෝර්වීජියානු බොක්මල්',
        'nd' => 'උතුරු එන්ඩිබෙලෙ',
        'nds' => 'පහළ ජර්මන්',
        'ne' => 'නේපාල',
        'new' => 'නෙවාරි',
        'ng' => 'න්ඩොන්ගා',
        'nia' => 'නියාස්',
        'niu' => 'නියුඑන්',
        'nl' => 'ලන්දේසි',
        'nmg' => 'කුවාසිඔ',
        'nn' => 'නෝර්වීජියානු නයිනෝර්ස්ක්',
        'nnh' => 'න්ගියාම්බූන්',
        'no' => 'නෝර්වීජියානු',
        'nog' => 'නොගායි',
        'nqo' => 'එන්‘කෝ',
        'nr' => 'සෞත් ඩ්බේල්',
        'nso' => 'නොදර්න් සොතො',
        'nus' => 'නොයර්',
        'nv' => 'නවාජො',
        'ny' => 'න්යන්ජා',
        'nyn' => 'නයන්කෝලෙ',
        'oc' => 'ඔසිටාන්',
        'ojb' => 'වයඹ ඔජිබ්වා',
        'ojc' => 'මධ්‍යම ඔජිබ්වා',
        'ojs' => 'ඔජි-ක්‍රී',
        'ojw' => 'බටහිර ඔජිබ්වා',
        'oka' => 'ඔකනගන්',
        'om' => 'ඔරොමෝ',
        'or' => 'ඔඩියා',
        'os' => 'ඔසිටෙක්',
        'pa' => 'පන්ජාබි',
        'pag' => 'පන්ගසීනන්',
        'pam' => 'පන්පන්ග',
        'pap' => 'පපියමෙන්ටො',
        'pau' => 'පලවුවන්',
        'pcm' => 'නෛජීරියන් පෙන්ගින්',
        'pis' => 'පිජින්',
        'pl' => 'පෝලන්ත',
        'pqm' => 'මලිසීට්-පස්සමකුඩි',
        'prg' => 'පෘශියන්',
        'ps' => 'පෂ්ටො',
        'pt' => 'පෘතුගීසි',
        'qu' => 'ක්වීචුවා',
        'quc' => 'කියිචේ',
        'rap' => 'රපනුයි',
        'rar' => 'රරොටොන්ගන්',
        'rhg' => 'රෝහින්ග්‍යා',
        'rm' => 'රොමෑන්ශ්',
        'rn' => 'රුන්ඩි',
        'ro' => 'රොමේනියානු',
        'rof' => 'රෝම්බෝ',
        'ru' => 'රුසියානු',
        'rup' => 'ඇරොමානියානු',
        'rw' => 'කින්යර්වන්ඩා',
        'rwk' => 'ර්වා',
        'sa' => 'සංස්කෘත',
        'sad' => 'සන්ඩවෙ',
        'sah' => 'සඛා',
        'saq' => 'සම්බුරු',
        'sat' => 'සෑන්ටලි',
        'sba' => 'න්ගම්බෙ',
        'sbp' => 'සංගු',
        'sc' => 'සාර්ඩිනිඅන්',
        'scn' => 'සිසිලියන්',
        'sco' => 'ස්කොට්ස්',
        'sd' => 'සින්ධි',
        'sdh' => 'දකුණු කුර්දි',
        'se' => 'උතුරු සාමි',
        'seh' => 'සෙනා',
        'ses' => 'කෝයිරාබොරො සෙන්නි',
        'sg' => 'සන්ග්‍රෝ',
        'shi' => 'ටචේල්හිට්',
        'shn' => 'ශාන්',
        'si' => 'සිංහල',
        'sk' => 'ස්ලෝවැක්',
        'sl' => 'ස්ලෝවේනියානු',
        'slh' => 'දකුණු ලුෂූට්සීඩ්',
        'sm' => 'සෑමොඅන්',
        'sma' => 'දකුණු සාමි',
        'smj' => 'ලුලේ සාමි',
        'smn' => 'ඉනාරි සාමි',
        'sms' => 'ස්කොල්ට් සාමි',
        'sn' => 'ශෝනා',
        'snk' => 'සොනින්කෙ',
        'so' => 'සෝමාලි',
        'sq' => 'ඇල්බේනියානු',
        'sr' => 'සර්බියානු',
        'srn' => 'ස්‍රන් ටොන්ගො',
        'ss' => 'ස්වති',
        'ssy' => 'සහො',
        'st' => 'සතර්න් සොතො',
        'str' => 'සාලිෂ්ස මුද්ර සන්ධිය',
        'su' => 'සන්ඩනීසියානු',
        'suk' => 'සුකුමා',
        'sv' => 'ස්වීඩන්',
        'sw' => 'ස්වාහිලි',
        'swb' => 'කොමොරියන්',
        'syr' => 'ස්‍රයෑක්',
        'ta' => 'දෙමළ',
        'tce' => 'දකුණු ටචෝන්',
        'te' => 'තෙළිඟු',
        'tem' => 'ටිම්නෙ',
        'teo' => 'ටෙසෝ',
        'tet' => 'ටේටම්',
        'tg' => 'ටජික්',
        'tgx' => 'ටැගිෂ්',
        'th' => 'තායි',
        'tht' => 'ටැල්ටන්',
        'ti' => 'ටිග්‍රින්යා',
        'tig' => 'ටීග්‍රෙ',
        'tk' => 'ටර්ක්මෙන්',
        'tlh' => 'ක්ලින්ගොන්',
        'tli' => 'ට්ලින්ගිට්',
        'tn' => 'ස්වනා',
        'to' => 'ටොංගා',
        'tok' => 'ටෝකි පොනා',
        'tpi' => 'ටොක් පිසින්',
        'tr' => 'තුර්කි',
        'trv' => 'ටරොකො',
        'ts' => 'සොන්ග',
        'tt' => 'ටාටර්',
        'ttm' => 'උතුරු ටචෝන්',
        'tum' => 'ටුම්බුකා',
        'tvl' => 'ටුවාලු',
        'twq' => 'ටසවාක්',
        'ty' => 'ටහිටියන්',
        'tyv' => 'ටුවිනියන්',
        'tzm' => 'මධ්‍යම ඇට්ලස් ටමසිට්',
        'udm' => 'අඩ්මර්ට්',
        'ug' => 'උයිගර්',
        'uk' => 'යුක්රේනියානු',
        'umb' => 'උබුන්ඩු',
        'ur' => 'උර්දු',
        'uz' => 'උස්බෙක්',
        'vai' => 'වයි',
        've' => 'වෙන්ඩා',
        'vi' => 'වියට්නාම්',
        'vo' => 'වොලපූක්',
        'vun' => 'වුන්ජෝ',
        'wa' => 'වෑලූන්',
        'wae' => 'වොල්සර්',
        'wal' => 'වොලෙට්ට',
        'war' => 'වොරෙය්',
        'wbp' => 'වොපිරි',
        'wo' => 'වොලොෆ්',
        'wuu' => 'වූ චයිනිස්',
        'xal' => 'කල්මික්',
        'xh' => 'ශෝසා',
        'xog' => 'සොගා',
        'yav' => 'යන්ග්බෙන්',
        'ybb' => 'යෙම්බා',
        'yi' => 'යිඩිශ්',
        'yo' => 'යොරූබා',
        'yrl' => 'නොහීඟටු',
        'yue' => 'කැන්ටොනීස්',
        'zgh' => 'සම්මත මොරොක්කෝ ටමසිග්ත්',
        'zh' => 'චීන',
        'zu' => 'සුලු',
        'zun' => 'සුනි',
        'zza' => 'සාසා',
    ],
    'LocalizedNames' => [
        'ar_001' => 'නූතන සම්මත අරාබි',
        'de_AT' => 'ඔස්ට්‍රියානු ජර්මන්',
        'de_CH' => 'ස්විස් උසස් ජර්මන්',
        'en_AU' => 'ඕස්ට්‍රේලියානු ඉංග්‍රීසි',
        'en_CA' => 'කැනේඩියානු ඉංග්‍රීසි',
        'en_GB' => 'බ්‍රිතාන්‍ය ඉංග්‍රීසි',
        'en_US' => 'ඇමෙරිකානු ඉංග්‍රීසි',
        'es_419' => 'ලතින් ඇමරිකානු ස්පාඤ්ඤ',
        'es_ES' => 'යුරෝපීය ස්පාඤ්ඤ',
        'es_MX' => 'මෙක්සිකානු ස්පාඤ්ඤ',
        'fa_AF' => 'ඩාරි',
        'fr_CA' => 'කැනේඩියානු ප්‍රංශ',
        'fr_CH' => 'ස්විස් ප්‍රංශ',
        'nds_NL' => 'පහළ සැක්සන්',
        'nl_BE' => 'ෆ්ලෙමිශ්',
        'pt_BR' => 'බ්‍රසීල පෘතුගීසි',
        'pt_PT' => 'යුරෝපීය පෘතුගීසි',
        'ro_MD' => 'මොල්ඩවිආනු',
        'sw_CD' => 'කොංගෝ ස්වාහිලි',
        'zh_Hans' => 'සරල චීන',
        'zh_Hant' => 'සාම්ප්‍රදායික චීන',
    ],
];
